@@ -971,6 +971,6 @@ impl App {
 fn clear_caches() {
     file_sum::clear_cache();
     git::clear_status_computer_cache();
-    #[cfg(unix)]
+    #[cfg(any(target_os = "macos", target_os = "linux"))]
     crate::filesystems::clear_cache();
 }
