@@ -1,4 +1,4 @@
-// Warning: this module can't import broot's stuf due to its use in build.rs
+// Warning: this module can't import broot's stuff due to its use in build.rs
 use {
     clap::{Parser, ValueEnum},
     std::{
@@ -44,6 +44,10 @@ pub struct Args {
     #[arg(long)]
     pub show_root_fs: bool,
 
+    /// Only show trees up to a certain depth
+    #[arg(long)]
+    pub max_depth: Option<u16>,
+
     /// Show git statuses on files and stats on repo
     #[arg(short='g', long)]
     pub show_git_info: bool,
@@ -128,6 +132,10 @@ pub struct Args {
     #[arg(short, long)]
     pub whale_spotting: bool,
 
+    /// No sort, no show hidden, no show git ignored
+    #[arg(short='W', long)]
+    pub no_whale_spotting: bool,
+
     /// Trim the root too and don't show a scrollbar
     #[arg(short='t', long)]
     pub trim_root: bool,
