@@ -6,7 +6,7 @@ use {
     image::{
         DynamicImage,
         GenericImageView,
-        io::Reader,
+        ImageReader,
         imageops::FilterType,
     },
     std::{
@@ -25,9 +25,10 @@ use {
 pub const MAX_SVG_BITMAP_WIDTH: u32 = 1000;
 pub const MAX_SVG_BITMAP_HEIGHT: u32 = 1000;
 
+#[allow(clippy::large_enum_variant)]
 pub enum SourceImage {
     Bitmap(DynamicImage),
-    Svg(resvg::Tree),
+    Svg(resvg::usvg::Tree),
 }
 
 impl SourceImage {
@@ -36,7 +37,7 @@ impl SourceImage {
         let img = if is_svg {
             Self::Svg(svg::load(path)?)
         } else {
-            Self::Bitmap(Reader::open(path)?.decode()?)
+            Self::Bitmap(ImageReader::open(path)?.decode()?)
         };
         Ok(img)
     }
@@ -44,8 +45,8 @@ impl SourceImage {
         match self {
             Self::Bitmap(img) => img.dimensions(),
             Self::Svg(tree) => (
-                f32_to_u32(tree.size.width()),
-                f32_to_u32(tree.size.height())
+                f32_to_u32(tree.size().width()),
+                f32_to_u32(tree.size().height())
             )
         }
     }
@@ -69,7 +70,7 @@ impl SourceImage {
         };
         Ok(img)
     }
-    pub fn optimal(&self) -> Result<Cow<DynamicImage>, ProgramError> {
+    pub fn optimal(&self) -> Result<Cow<'_, DynamicImage>, ProgramError> {
         let cow = match self {
             Self::Bitmap(img) => Cow::Borrowed(img),
             Self::Svg(tree) => Cow::Owned(
