@@ -30,14 +30,17 @@ pub mod skin;
 pub mod syntactic;
 pub mod task_sync;
 pub mod terminal;
-pub mod trash;
 pub mod tree;
 pub mod tree_build;
+pub mod tty;
 pub mod verb;
 
-#[cfg(unix)]
+#[cfg(any(target_os = "macos", target_os = "linux"))]
 pub mod filesystems;
 
-
 #[cfg(unix)]
 pub mod net;
+
+#[cfg(feature = "trash")]
+pub mod trash;
+
